@@ -1,28 +1,29 @@
 package Template::Caribou::Utils;
-BEGIN {
-  $Template::Caribou::Utils::AUTHORITY = 'cpan:YANICK';
-}
-$Template::Caribou::Utils::VERSION = '0.2.4';
+our $AUTHORITY = 'cpan:YANICK';
+# ABSTRACT: internal utilities for Template::Caribou
+$Template::Caribou::Utils::VERSION = '1.0.0';
+
 use strict;
 use warnings;
 no warnings qw/ uninitialized /;
 
-use Carp;
-
-use Moose;
-
 BEGIN {
     *::RAW = *::STDOUT;
 }
 
+use parent 'Exporter::Tiny';
+
+use experimental 'signatures';
+
+use Carp;
 
-__PACKAGE__->meta->make_immutable;
 
 package
     Template::Caribou::String;
 
 use overload 
-    '""' => sub { return ${$_[0] } };
+    '""' => sub { return ${$_[0] } },
+    'eq' => sub { ${$_[0]} eq $_[1] };
 
 sub new { my ( $class, $string ) = @_;  bless \$string, $class; }
 
@@ -71,11 +72,16 @@ __END__
 
 =head1 NAME
 
-Template::Caribou::Utils
+Template::Caribou::Utils - internal utilities for Template::Caribou
 
 =head1 VERSION
 
-version 0.2.4
+version 1.0.0
+
+=head1 DESCRIPTION
+
+Used internally by L<Template::Caribou>. Nothing interesting
+for end-users.
 
 =head1 AUTHOR
 
@@ -83,7 +89,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yanick Champoux.
+This software is copyright (c) 2017 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
